aboutsummaryrefslogtreecommitdiff
path: root/modules/users/shells/zsh
diff options
context:
space:
mode:
Diffstat (limited to 'modules/users/shells/zsh')
-rw-r--r--modules/users/shells/zsh/default.nix27
1 files changed, 15 insertions, 12 deletions
diff --git a/modules/users/shells/zsh/default.nix b/modules/users/shells/zsh/default.nix
index 5a48cf0..0b94c3d 100644
--- a/modules/users/shells/zsh/default.nix
+++ b/modules/users/shells/zsh/default.nix
@@ -28,20 +28,23 @@ in
autosuggestion.enable = true;
syntaxHighlighting.enable = true;
initContent = ''
- # view man pages with nvim
- export MANPAGER="nvim +Man!"
+ # view man pages with nvim
+ export MANPAGER="nvim +Man!"
- # Directory completion with trailing slash
- zstyle ':completion:*' list-dirs-first true
- zstyle ':completion:*' special-dirs true
- zstyle ':completion:*' squeeze-slashes true
- zstyle ':completion:*' add-space false
+ # Directory completion with trailing slash
+ zstyle ':completion:*' list-dirs-first true
+ zstyle ':completion:*' special-dirs true
+ zstyle ':completion:*' squeeze-slashes true
+ zstyle ':completion:*' add-space false
- # Case-insensitive completion
- zstyle ':completion:*' matcher-list 'm:{a-z}={A-Z}'
- # vim keybindings
- bindkey -v
- '';
+ # Case-insensitive completion
+ zstyle ':completion:*' matcher-list 'm:{a-z}={A-Z}'
+ # vim keybindings
+ bindkey -v
+
+ # zoxide smarter cmd command
+ eval "$(zoxide init zsh)"
+ '';
shellAliases = {
ls = "ls --color=auto";
};